@@ -287,7 +287,7 @@ get_space_left (const char *path)
 static ssize_t
 read_blocks (dvd_file_t *file, size_t offset, size_t size, unsigned char *buffer)
 {
-  ssize_t count, skip;
+  ssize_t count = 0, skip;
 
   for (skip = 0; skip < size; skip ++)
   {
