@@ -306,8 +306,8 @@ static OGMDvdStream *
 ogmdvd_audio_stream_new (OGMDvdTitle *title, ifo_handle_t *vts_file, guint nr, guint real_nr)
 {
   OGMDvdAudioStream *stream;
-
   audio_attr_t *attr;
+  guint16 pgcn;
 
   stream = g_new0 (OGMDvdAudioStream, 1);
   stream->stream.title = title;
@@ -320,7 +320,8 @@ ogmdvd_audio_stream_new (OGMDvdTitle *title, ifo_handle_t *vts_file, guint nr, g
   stream->code_extension = attr->code_extension;
   stream->lang_code = attr->lang_code;
 
-  stream->stream.id = vts_file->vts_pgcit->pgci_srp[title->ttn - 1].pgc->audio_control[real_nr] >> 8 & 7;
+  pgcn = vts_file->vts_ptt_srpt->title[title->ttn - 1].ptt[0].pgcn;
+  stream->stream.id = vts_file->vts_pgcit->pgci_srp[pgcn - 1].pgc->audio_control[real_nr] >> 8 & 7;
 
   return (OGMDvdStream *) stream;
 }
@@ -330,6 +331,7 @@ ogmdvd_subp_stream_new (OGMDvdTitle *title, ifo_handle_t *vts_file, guint nr, gu
 {
   OGMDvdSubpStream *stream;
   subp_attr_t *attr;
+  guint16 pgcn;
 
   stream = g_new0 (OGMDvdSubpStream, 1);
   stream->stream.title = title;
@@ -339,11 +341,13 @@ ogmdvd_subp_stream_new (OGMDvdTitle *title, ifo_handle_t *vts_file, guint nr, gu
   stream->lang_extension = attr->lang_extension;
   stream->lang_code = attr->lang_code;
 
+  pgcn = vts_file->vts_ptt_srpt->title[title->ttn - 1].ptt[0].pgcn;
+
   stream->stream.id = nr;
   if (title->display_aspect_ratio == 0) /* 4:3 */
-    stream->stream.id = vts_file->vts_pgcit->pgci_srp[title->ttn - 1].pgc->subp_control[real_nr] >> 24 & 31;
+    stream->stream.id = vts_file->vts_pgcit->pgci_srp[pgcn - 1].pgc->subp_control[real_nr] >> 24 & 31;
   else if (title->display_aspect_ratio == 3) /* 16:9 */
-    stream->stream.id = vts_file->vts_pgcit->pgci_srp[title->ttn - 1].pgc->subp_control[real_nr] >> 8 & 31;
+    stream->stream.id = vts_file->vts_pgcit->pgci_srp[pgcn - 1].pgc->subp_control[real_nr] >> 8 & 31;
 
   return (OGMDvdStream *) stream;
 }
@@ -419,7 +423,7 @@ ogmdvd_title_new (OGMDvdDisc *disc, dvd_reader_t *reader, ifo_handle_t *vmg_file
 
   for (i = 0; i < vts_file->vtsi_mat->nr_of_vts_audio_streams; i++)
   {
-    if (vts_file->vts_pgcit->pgci_srp[title->ttn - 1].pgc->audio_control[i] & 0x8000)
+    if (vts_file->vts_pgcit->pgci_srp[pgcn - 1].pgc->audio_control[i] & 0x8000)
     {
       stream = ogmdvd_audio_stream_new (title, vts_file, title->nr_of_audio_streams, i);
       if (stream)
@@ -430,7 +434,7 @@ ogmdvd_title_new (OGMDvdDisc *disc, dvd_reader_t *reader, ifo_handle_t *vmg_file
 
   for (i = 0; i < vts_file->vtsi_mat->nr_of_vts_subp_streams; i++)
   {
-    if (vts_file->vts_pgcit->pgci_srp[title->ttn - 1].pgc->subp_control[i] & 0x80000000)
+    if (vts_file->vts_pgcit->pgci_srp[pgcn - 1].pgc->subp_control[i] & 0x80000000)
     {
       stream = ogmdvd_subp_stream_new (title, vts_file, title->nr_of_subp_streams, i);
       if (stream)
