@@ -1,5 +1,5 @@
 /* OGMJob - A library to spawn processes
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -104,15 +104,11 @@ ogmjob_bin_add (OGMJobContainer *container, OGMJobSpawn *child)
   bin = OGMJOB_BIN (container);
   if (bin->priv->child == NULL)
   {
-    guint handler;
-
     g_object_ref (child);
     bin->priv->child = child;
 
-    handler = g_signal_connect_swapped (child, "progress", 
+    g_signal_connect_swapped (child, "progress", 
         G_CALLBACK (ogmjob_bin_child_progress), container);
-    g_object_set_data (G_OBJECT (child), "__child_progress_handler__", 
-        GUINT_TO_POINTER (handler));
   }
 }
 
@@ -124,11 +120,8 @@ ogmjob_bin_remove (OGMJobContainer *container, OGMJobSpawn *child)
   bin = OGMJOB_BIN (container);
   if (bin->priv->child == child)
   {
-    gpointer handler;
-
-    handler = g_object_get_data (G_OBJECT (child), "__child_progress_handler__");
-    if (handler)
-      g_signal_handler_disconnect (child, GPOINTER_TO_UINT (handler));
+    g_signal_handlers_disconnect_by_func (child,
+        ogmjob_bin_child_progress, container);
 
     g_object_unref (child);
     bin->priv->child = NULL;
