@@ -1,5 +1,5 @@
-/* OGMRip - A wrapper library around libdvdread
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+/* OGMRip - A library for DVD ripping and encoding
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -207,7 +207,12 @@ ogmrip_source_chooser_construct_file_chooser_dialog (gboolean audio)
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 
+#if GTK_CHECK_VERSION(2,24,0)
+  combo = gtk_combo_box_text_new ();
+#else
   combo = gtk_combo_box_new_text ();
+#endif
+
   gtk_box_pack_start (GTK_BOX (hbox), combo, TRUE, TRUE, 0);
   gtk_widget_show (combo);
 
@@ -231,7 +236,11 @@ ogmrip_source_chooser_construct_file_chooser_dialog (gboolean audio)
   {
     str = g_strdup_printf ("%s (%s)", ogmdvd_languages[i][OGMDVD_LANGUAGE_NAME],
         ogmdvd_languages[i][OGMDVD_LANGUAGE_ISO639_1]);
+#if GTK_CHECK_VERSION(2,24,0)
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), str);
+#else
     gtk_combo_box_append_text (GTK_COMBO_BOX (combo), str);
+#endif
     g_free (str);
 
     if (strncmp (ogmdvd_languages[i][OGMDVD_LANGUAGE_ISO639_1], lang, 2) == 0)
