@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -246,7 +246,9 @@ ogmrip_x264_dialog_init (OGMRipX264Dialog *dialog)
       NULL);
   gtk_window_set_title (GTK_WINDOW (dialog), _("X264 Options"));
   gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+#if !GTK_CHECK_VERSION(2,22,0)
   gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+#endif
   gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
   gtk_window_set_icon_from_stock (GTK_WINDOW (dialog), GTK_STOCK_PREFERENCES);
@@ -297,8 +299,15 @@ ogmrip_x264_dialog_init (OGMRipX264Dialog *dialog)
   gtk_widget_set_sensitive (dialog->me_combo, x264_have_me);
 
   if (x264_have_me_tesa)
-    gtk_combo_box_append_text (GTK_COMBO_BOX (dialog->me_combo),
-        _("Transformed Exhaustive search (tesa - even slower)"));
+  {
+    GtkTreeModel *model;
+    GtkTreeIter iter;
+
+    model = gtk_combo_box_get_model (GTK_COMBO_BOX (dialog->me_combo));
+    gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+    gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+        0, _("Transformed Exhaustive search (tesa - even slower)"), -1);
+  }
 
   dialog->merange_spin = glade_xml_get_widget (xml, "merange-spin");
   gtk_widget_set_sensitive (dialog->merange_spin, x264_have_me);
