@@ -87,6 +87,10 @@ ogmrip_audio_copy_command (OGMRipAudioCodec *audio, const gchar *input, const gc
 
     argv = ogmrip_mencoder_audio_command (audio, output);
 
+    g_ptr_array_add (argv, g_strdup ("-noskip"));
+    g_ptr_array_add (argv, g_strdup ("-mc"));
+    g_ptr_array_add (argv, g_strdup ("0"));
+
     g_ptr_array_add (argv, g_strdup ("-ovc"));
     if (MPLAYER_CHECK_VERSION (1,0,0,8))
     {
