@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -465,7 +465,7 @@ ogmrip_audio_codec_set_label (OGMRipAudioCodec *audio, const gchar *label)
  *
  * Returns: the track name
  */
-G_CONST_RETURN gchar *
+const gchar *
 ogmrip_audio_codec_get_label (OGMRipAudioCodec *audio)
 {
   g_return_val_if_fail (OGMRIP_IS_AUDIO_CODEC (audio), NULL);
