@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -71,8 +71,7 @@ void                ogmrip_audio_codec_set_sample_rate       (OGMRipAudioCodec
 gint                ogmrip_audio_codec_get_sample_rate       (OGMRipAudioCodec    *audio);
 void                ogmrip_audio_codec_set_label             (OGMRipAudioCodec    *audio,
                                                               const gchar         *label);
-G_CONST_RETURN
-gchar *             ogmrip_audio_codec_get_label             (OGMRipAudioCodec    *audio);
+const gchar *       ogmrip_audio_codec_get_label             (OGMRipAudioCodec    *audio);
 gint                ogmrip_audio_codec_get_samples_per_frame (OGMRipAudioCodec    *audio);
 
 G_END_DECLS
