@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -205,7 +205,7 @@ ogmrip_chapters_set_label (OGMRipChapters *chapters, guint n, const gchar *label
  *
  * Returns: The label
  */
-G_CONST_RETURN gchar *
+const gchar *
 ogmrip_chapters_get_label (OGMRipChapters *chapters, guint n)
 {
   g_return_val_if_fail (OGMRIP_IS_CHAPTERS (chapters), NULL);
