@@ -172,7 +172,7 @@ ogmrip_codec_finalize (GObject *gobject)
 
   if (codec->priv->output)
   {
-    if (codec->priv->do_unlink && g_file_test (codec->priv->output, G_FILE_TEST_IS_REGULAR))
+    if (codec->priv->do_unlink)
       g_unlink (codec->priv->output);
 
     g_free (codec->priv->output);
