@@ -89,11 +89,8 @@ static void
 ogmrip_container_class_init (OGMRipContainerClass *klass)
 {
   GObjectClass *gobject_class;
-  OGMJobSpawnClass *spawn_class;
 
   gobject_class = G_OBJECT_CLASS (klass);
-  spawn_class = OGMJOB_SPAWN_CLASS (klass);
-
   gobject_class->dispose  = ogmrip_container_dispose;
   gobject_class->finalize = ogmrip_container_finalize;
   gobject_class->set_property = ogmrip_container_set_property;
@@ -1208,9 +1205,8 @@ ogmrip_container_child_get_size (OGMRipContainerChild *child)
   guint64 size = 0;
 
   filename = ogmrip_codec_get_output (child->codec);
-  if (filename && g_file_test (filename, G_FILE_TEST_IS_REGULAR))
-    if (g_stat (filename, &buf) == 0)
-      size = (guint64) buf.st_size;
+  if (filename && g_stat (filename, &buf) == 0)
+    size = (guint64) buf.st_size;
 
   return size;
 }
