@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -217,7 +217,7 @@ ogmrip_edl_dump (OGMRipEdl *edl)
  *
  * Returns: The filename
  */
-G_CONST_RETURN gchar *
+const gchar *
 ogmrip_edl_get_filename (OGMRipEdl *edl)
 {
   g_return_val_if_fail (edl != NULL, NULL);
