@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -135,7 +135,7 @@ ogmrip_lavc_get_quantizer (OGMRipVideoCodec *video)
   return CLAMP (quantizer, 2, 31);
 }
 
-static G_CONST_RETURN gchar *
+static const gchar *
 ogmrip_lavc_get_codec (OGMRipLavc *lavc)
 {
   OGMRipLavcClass *klass;
