@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -69,7 +69,7 @@ struct _OGMRipLavcClass
   OGMRipVideoCodecClass parent_class;
 
   /* vtable */
-  G_CONST_RETURN gchar * (* get_codec) (void);
+  const gchar * (* get_codec) (void);
 };
 
 /**
