@@ -38,6 +38,61 @@
 
 static const gchar *deinterlacer[] = { "lb", "li", "ci", "md", "fd", "l5", "kerndeint", "yadif" };
 
+static GPtrArray *
+ogmrip_command_new (const gchar *command, gboolean lavf)
+{
+  GPtrArray *argv;
+
+  argv = g_ptr_array_new ();
+  g_ptr_array_add (argv, g_strdup (command));
+
+  g_ptr_array_add (argv, g_strdup ("-nocache"));
+  g_ptr_array_add (argv, g_strdup ("-noslices"));
+
+  if (MPLAYER_CHECK_VERSION (1,0,3,0))
+  {
+    g_ptr_array_add (argv, g_strdup ("-noconfig"));
+    g_ptr_array_add (argv, g_strdup ("all"));
+  }
+
+  if (lavf)
+  {
+    g_ptr_array_add (argv, g_strdup ("-demuxer"));
+    g_ptr_array_add (argv, g_strdup ("+lavf"));
+  }
+
+  return argv;
+}
+
+static GPtrArray *
+ogmrip_mplayer_command_new (gboolean lavf)
+{
+  GPtrArray *argv;
+
+  argv = ogmrip_command_new ("mplayer", lavf);
+  g_ptr_array_add (argv, g_strdup ("-nolirc"));
+  g_ptr_array_add (argv, g_strdup ("-noframedrop"));
+  g_ptr_array_add (argv, g_strdup ("-nocorrect-pts"));
+
+  return argv;
+}
+
+static GPtrArray *
+ogmrip_mencoder_command_new (const gchar *output, gboolean lavf)
+{
+  GPtrArray *argv;
+
+  argv = ogmrip_command_new ("mencoder", lavf);
+
+  if (output)
+  {
+    g_ptr_array_add (argv, g_strdup ("-o"));
+    g_ptr_array_add (argv, g_strdup (output));
+  }
+
+  return argv;
+}
+
 static gint
 ogmrip_mplayer_map_audio_id (OGMDvdAudioStream *astream)
 {
@@ -64,7 +119,7 @@ ogmrip_mplayer_map_audio_id (OGMDvdAudioStream *astream)
   return aid;
 }
 
-glong
+static glong
 ogmrip_mplayer_get_frames (OGMRipCodec *codec)
 {
   gdouble length;
@@ -76,8 +131,8 @@ ogmrip_mplayer_get_frames (OGMRipCodec *codec)
   return length / (gdouble) denom * num;
 }
 
-static gchar *
-ogmrip_mplayer_get_output_fps (OGMRipCodec *codec, OGMDvdTitle *title)
+static void
+ogmrip_mplayer_set_output_fps (GPtrArray *argv, OGMRipCodec *codec, OGMDvdTitle *title)
 {
   guint rate_numerator, rate_denominator;
   guint output_rate_numerator, output_rate_denominator;
@@ -95,13 +150,14 @@ ogmrip_mplayer_get_output_fps (OGMRipCodec *codec, OGMDvdTitle *title)
   step = ogmrip_codec_get_framestep (codec); 
 
   if (rate_numerator != output_rate_numerator || rate_denominator != output_rate_denominator * step)
-    return g_strdup_printf ("%d/%d", output_rate_numerator, output_rate_denominator * step);
-
-  return NULL;
+  {
+    g_ptr_array_add (argv, g_strdup ("-ofps"));
+    g_ptr_array_add (argv, g_strdup_printf ("%d/%d", output_rate_numerator, output_rate_denominator * step));
+  }
 }
 
-static gchar *
-ogmrip_mplayer_get_chapters (OGMRipCodec *codec, OGMDvdTitle *title)
+static void
+ogmrip_mplayer_set_chapters (GPtrArray *argv, OGMRipCodec *codec, OGMDvdTitle *title)
 {
   guint start, end;
   gint n_chap;
@@ -122,10 +178,32 @@ ogmrip_mplayer_get_chapters (OGMRipCodec *codec, OGMDvdTitle *title)
     else
       str = g_strdup_printf ("%d", start + 1);
 
-    return str;
+    g_ptr_array_add (argv, g_strdup ("-chapter"));
+    g_ptr_array_add (argv, str);
+  }
+}
+
+static void
+ogmrip_mplayer_set_start_length (GPtrArray *argv, OGMRipCodec *codec)
+{
+  gdouble start, length;
+
+  start = ogmrip_codec_get_start (codec);
+  if (start > 0.0)
+  {
+    g_ptr_array_add (argv, g_strdup ("-ss"));
+    g_ptr_array_add (argv, g_strdup_printf ("%.0lf", start));
   }
 
-  return NULL;
+  length = ogmrip_codec_get_play_length (codec);
+  if (length > 0.0)
+  {
+    guint num, denom;
+
+    ogmrip_codec_get_framerate (codec, &num, &denom);
+    g_ptr_array_add (argv, g_strdup ("-frames"));
+    g_ptr_array_add (argv, g_strdup_printf ("%.0lf", length * num / denom));
+  }
 }
 
 static gboolean
@@ -213,6 +291,147 @@ ogmrip_mplayer_append_edl (OGMRipCodec *codec, GPtrArray *argv, gboolean hr)
   }
 }
 
+static gboolean
+ogmrip_mplayer_set_video_filter (GPtrArray *argv, OGMRipVideoCodec *video)
+{
+  GString *options, *pp;
+  guint max_width, max_height;
+  guint scale_width, scale_height;
+  guint crop_x, crop_y, crop_width, crop_height;
+  gboolean expand, scale;
+
+  options = g_string_new (NULL);
+  pp = g_string_new (NULL);
+
+  if (ogmrip_video_codec_get_deblock (video))
+  {
+    if (pp->len > 0)
+      g_string_append_c (pp, '/');
+    g_string_append (pp, "ha/va");
+  }
+
+  if (ogmrip_video_codec_get_dering (video))
+  {
+    if (pp->len > 0)
+      g_string_append_c (pp, '/');
+    g_string_append (pp, "dr");
+  }
+
+  if (ogmrip_codec_get_telecine (OGMRIP_CODEC (video)))
+  {
+    if (options->len > 0)
+      g_string_append_c (options, ',');
+    g_string_append (options, "pullup,softskip");
+  }
+
+  if (ogmrip_video_codec_get_crop_size (video, &crop_x, &crop_y, &crop_width, &crop_height))
+  {
+    if (options->len > 0)
+      g_string_append_c (options, ',');
+    g_string_append_printf (options, "crop=%u:%u:%u:%u", crop_width, crop_height, crop_x, crop_y);
+  }
+
+  ogmrip_mplayer_set_deint (video, argv, options, pp);
+
+  if (pp->len > 0)
+  {
+    if (options->len > 0)
+      g_string_append_c (options, ',');
+    g_string_append_printf (options, "pp=%s", pp->str);
+  }
+  g_string_free (pp, TRUE);
+
+  scale = ogmrip_video_codec_get_scale_size (video, &scale_width, &scale_height);
+  if (scale)
+  {
+    if (options->len > 0)
+      g_string_append_c (options, ',');
+    g_string_append_printf (options, "scale=%u:%u", scale_width, scale_height);
+
+    if (ogmrip_video_codec_is_interlaced (video) > 0 && ogmrip_video_codec_get_deinterlacer (video) == OGMRIP_DEINT_NONE)
+      g_string_append (options, ":1");
+  }
+
+  if (ogmrip_video_codec_get_max_size (video, &max_width, &max_height, &expand) && expand)
+  {
+    if (options->len > 0)
+      g_string_append_c (options, ',');
+    g_string_append_printf (options, "expand=%u:%u", max_width, max_height);
+  }
+
+  if (ogmrip_video_codec_get_denoise (video))
+  {
+    if (options->len > 0)
+      g_string_append_c (options, ',');
+    g_string_append (options, "hqdn3d=2:1:2");
+  }
+
+  if (options->len > 0)
+    g_string_append_c (options, ',');
+  g_string_append (options, "harddup");
+
+  if (options->len == 0)
+    g_string_free (options, TRUE);
+  else
+  {
+    g_ptr_array_add (argv, g_strdup ("-vf"));
+    g_ptr_array_add (argv, g_string_free (options, FALSE));
+  }
+
+  return scale;
+}
+
+static void
+ogmrip_mplayer_set_aid (GPtrArray *argv, OGMDvdAudioStream *stream)
+{
+  if (!stream)
+    g_ptr_array_add (argv, g_strdup ("-nosound"));
+  else
+  {
+    g_ptr_array_add (argv, g_strdup ("-aid"));
+    g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_mplayer_map_audio_id (stream)));
+  }
+}
+
+static void
+ogmrip_mplayer_set_sid (GPtrArray *argv, OGMDvdSubpStream *stream, gboolean forced)
+{
+  if (stream)
+  {
+    g_ptr_array_add (argv, g_strdup ("-spuaa"));
+    g_ptr_array_add (argv, g_strdup ("20"));
+    g_ptr_array_add (argv, g_strdup ("-sid"));
+    g_ptr_array_add (argv, g_strdup_printf ("%d",
+          ogmdvd_stream_get_id (OGMDVD_STREAM (stream))));
+
+    if (forced)
+      g_ptr_array_add (argv, g_strdup ("-forcedsubsonly"));
+  }
+  else if (ogmrip_check_mplayer_nosub ())
+    g_ptr_array_add (argv, g_strdup ("-nosub"));
+}
+
+static void
+ogmrip_mplayer_set_input (GPtrArray *argv, OGMDvdTitle *title)
+{
+  const gchar *device;
+  gint vid;
+
+  device = ogmdvd_disc_get_device (ogmdvd_title_get_disc (title));
+  g_ptr_array_add (argv, g_strdup ("-dvd-device"));
+  g_ptr_array_add (argv, g_strdup (device));
+
+  vid = ogmdvd_title_get_nr (title);
+
+  if (MPLAYER_CHECK_VERSION (1,0,0,1))
+    g_ptr_array_add (argv, g_strdup_printf ("dvd://%d", vid + 1));
+  else
+  {
+    g_ptr_array_add (argv, g_strdup ("-dvd"));
+    g_ptr_array_add (argv, g_strdup_printf ("%d", vid + 1));
+  }
+}
+
 static gint
 ogmrip_mplayer_audio_file_get_demuxer (OGMRipAudioFile *audio)
 {
@@ -301,11 +520,6 @@ ogmrip_mplayer_wav_command (OGMRipAudioCodec *audio, gboolean header, const gcha
   GPtrArray *argv;
   GString *options;
 
-  gdouble start, length;
-  const gchar *device;
-  gchar *chap;
-  gint vid;
-
   g_return_val_if_fail (OGMRIP_IS_AUDIO_CODEC (audio), NULL);
 
   if (!output)
@@ -318,28 +532,14 @@ ogmrip_mplayer_wav_command (OGMRipAudioCodec *audio, gboolean header, const gcha
   astream = ogmrip_audio_codec_get_dvd_audio_stream (audio);
   g_return_val_if_fail (astream != NULL, NULL);
 
-  argv = g_ptr_array_new ();
-  g_ptr_array_add (argv, g_strdup ("mplayer"));
-  g_ptr_array_add (argv, g_strdup ("-nolirc"));
-  g_ptr_array_add (argv, g_strdup ("-nocache"));
-  g_ptr_array_add (argv, g_strdup ("-noframedrop"));
-
-  if (MPLAYER_CHECK_VERSION (1,0,3,0))
-  {
-    g_ptr_array_add (argv, g_strdup ("-noconfig"));
-    g_ptr_array_add (argv, g_strdup ("all"));
-  }
-
-  length = ogmrip_codec_get_play_length (OGMRIP_CODEC (audio));
-
-  if (length <= 0.0)
-  {
-    g_ptr_array_add (argv, g_strdup ("-vc"));
-    g_ptr_array_add (argv, g_strdup ("dummy"));
-  }
+  argv = ogmrip_mplayer_command_new (TRUE);
 
+  g_ptr_array_add (argv, g_strdup ("-benchmark"));
+  g_ptr_array_add (argv, g_strdup ("-vc"));
+  g_ptr_array_add (argv, g_strdup ("null"));
   g_ptr_array_add (argv, g_strdup ("-vo"));
   g_ptr_array_add (argv, g_strdup ("null"));
+
   g_ptr_array_add (argv, g_strdup ("-ao"));
 
   if (MPLAYER_CHECK_VERSION (1,0,0,8))
@@ -420,47 +620,15 @@ ogmrip_mplayer_wav_command (OGMRipAudioCodec *audio, gboolean header, const gcha
   g_ptr_array_add (argv, g_strdup ("-channels"));
   g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_audio_codec_get_channels (audio) + 1));
 
-  chap = ogmrip_mplayer_get_chapters (OGMRIP_CODEC (audio), title);
-  if (chap)
-  {
-    g_ptr_array_add (argv, g_strdup ("-chapter"));
-    g_ptr_array_add (argv, chap);
-  }
+  ogmrip_mplayer_set_chapters (argv, OGMRIP_CODEC (audio), title);
 
-  start = ogmrip_codec_get_start (OGMRIP_CODEC (audio));
-  if (start > 0.0)
-  {
-    g_ptr_array_add (argv, g_strdup ("-ss"));
-    g_ptr_array_add (argv, g_strdup_printf ("%.0lf", start));
-  }
-
-  if (length > 0.0)
-  {
-    guint num, denom;
-
-    ogmrip_codec_get_framerate (OGMRIP_CODEC (audio), &num, &denom);
-    g_ptr_array_add (argv, g_strdup ("-frames"));
-    g_ptr_array_add (argv, g_strdup_printf ("%.0lf", length * num / denom));
-  }
+  ogmrip_mplayer_set_start_length (argv, OGMRIP_CODEC (audio));
 
   ogmrip_mplayer_append_edl (OGMRIP_CODEC (audio), argv, FALSE);
 
-  g_ptr_array_add (argv, g_strdup ("-aid"));
-  g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_mplayer_map_audio_id (astream)));
+  ogmrip_mplayer_set_aid (argv, astream);
 
-  device = ogmdvd_disc_get_device (ogmdvd_title_get_disc (title));
-  g_ptr_array_add (argv, g_strdup ("-dvd-device"));
-  g_ptr_array_add (argv, g_strdup (device));
-
-  vid = ogmdvd_title_get_nr (title);
-
-  if (MPLAYER_CHECK_VERSION (1,0,0,1))
-    g_ptr_array_add (argv, g_strdup_printf ("dvd://%d", vid + 1));
-  else
-  {
-    g_ptr_array_add (argv, g_strdup ("-dvd"));
-    g_ptr_array_add (argv, g_strdup_printf ("%d", vid + 1));
-  }
+  ogmrip_mplayer_set_input (argv, title);
 
   g_ptr_array_add (argv, NULL);
 
@@ -481,15 +649,15 @@ ogmrip_mplayer_wav_command (OGMRipAudioCodec *audio, gboolean header, const gcha
 gdouble
 ogmrip_mplayer_wav_watch (OGMJobExec *exec, const gchar *buffer, OGMRipAudioCodec *audio)
 {
-  gchar pos[12], pos_time[12], total[12];
+  gchar a[12], v[12];
   static gdouble start;
   gdouble secs;
 
   if (g_str_equal (buffer, "Starting playback..."))
     start = 0;
-  else if (sscanf (buffer, "A: %s %s of %s", pos, pos_time, total) == 3)
+  else if (sscanf (buffer, "A: %s V: %s", a, v) == 2)
   {
-    secs = strtod (pos, NULL);
+    secs = strtod (a, NULL);
     if (!start)
       start = secs;
 
@@ -514,66 +682,21 @@ ogmrip_mencoder_audio_command (OGMRipAudioCodec *audio, const gchar *output)
 {
   GPtrArray *argv;
   const gchar *device;
-  gdouble start, length;
-  gchar *ofps, *chap;
 
   OGMDvdTitle *title;
-  OGMDvdAudioStream *astream;
 
   g_return_val_if_fail (OGMRIP_IS_AUDIO_CODEC (audio), NULL);
 
   title = ogmrip_codec_get_input (OGMRIP_CODEC (audio));
 
-  argv = g_ptr_array_new ();
-
-  g_ptr_array_add (argv, g_strdup ("mencoder"));
-  g_ptr_array_add (argv, g_strdup ("-nocache"));
-
-  if (MPLAYER_CHECK_VERSION (1,0,3,0))
-  {
-    g_ptr_array_add (argv, g_strdup ("-noconfig"));
-    g_ptr_array_add (argv, g_strdup ("all"));
-  }
-
-  ofps = ogmrip_mplayer_get_output_fps (OGMRIP_CODEC (audio), title);
-  if (ofps)
-  {
-    g_ptr_array_add (argv, g_strdup ("-ofps"));
-    g_ptr_array_add (argv, ofps);
-  }
-
-  chap = ogmrip_mplayer_get_chapters (OGMRIP_CODEC (audio), title);
-  if (chap)
-  {
-    g_ptr_array_add (argv, g_strdup ("-chapter"));
-    g_ptr_array_add (argv, chap);
-  }
-
-  start = ogmrip_codec_get_start (OGMRIP_CODEC (audio));
-  if (start > 0.0)
-  {
-    g_ptr_array_add (argv, g_strdup ("-ss"));
-    g_ptr_array_add (argv, g_strdup_printf ("%.0lf", start));
-  }
-
-  length = ogmrip_codec_get_play_length (OGMRIP_CODEC (audio));
-  if (length > 0.0)
-  {
-    guint num, denom;
-
-    ogmrip_codec_get_framerate (OGMRIP_CODEC (audio), &num, &denom);
-    g_ptr_array_add (argv, g_strdup ("-frames"));
-    g_ptr_array_add (argv, g_strdup_printf ("%.0lf", length * num / denom));
-  }
+  argv = ogmrip_mencoder_command_new (output, TRUE);
 
+  ogmrip_mplayer_set_output_fps (argv, OGMRIP_CODEC (audio), title);
+  ogmrip_mplayer_set_chapters (argv, OGMRIP_CODEC (audio), title);
+  ogmrip_mplayer_set_start_length (argv, OGMRIP_CODEC (audio));
   ogmrip_mplayer_append_edl (OGMRIP_CODEC (audio), argv, TRUE);
 
-  g_ptr_array_add (argv, g_strdup ("-aid"));
-  astream = ogmrip_audio_codec_get_dvd_audio_stream (audio);
-  g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_mplayer_map_audio_id (astream)));
-
-  g_ptr_array_add (argv, g_strdup ("-o"));
-  g_ptr_array_add (argv, g_strdup (output));
+  ogmrip_mplayer_set_aid (argv, ogmrip_audio_codec_get_dvd_audio_stream (audio));
 
   device = ogmdvd_disc_get_device (ogmdvd_title_get_disc (title));
   g_ptr_array_add (argv, g_strdup ("-dvd-device"));
@@ -599,45 +722,25 @@ ogmrip_mencoder_video_command (OGMRipVideoCodec *video, const gchar *output, gui
   GPtrArray *argv;
   OGMDvdTitle *title;
 
-  gint format;
   const gchar *device;
-  gdouble start, length;
-  gchar *ofps, *chap;
-  gboolean scale;
+  gboolean scale = FALSE;
 
   title = ogmrip_codec_get_input (OGMRIP_CODEC (video));
 
-  format = ogmrip_plugin_get_video_codec_format (G_OBJECT_TYPE (video));
-
-  argv = g_ptr_array_new ();
-
-  g_ptr_array_add (argv, g_strdup ("mencoder"));
-  g_ptr_array_add (argv, g_strdup ("-nocache"));
-  g_ptr_array_add (argv, g_strdup ("-noslices"));
-
-  if (MPLAYER_CHECK_VERSION (1,0,3,0))
-  {
-    g_ptr_array_add (argv, g_strdup ("-noconfig"));
-    g_ptr_array_add (argv, g_strdup ("all"));
-  }
-
-  scale = FALSE;
-
-  if (format == OGMRIP_FORMAT_COPY)
-    g_ptr_array_add (argv, g_strdup ("-nosound"));
+  if (ogmrip_plugin_get_video_codec_format (G_OBJECT_TYPE (video)) == OGMRIP_FORMAT_COPY)
+    argv = ogmrip_mencoder_command_new (output, FALSE);
   else
   {
     OGMDvdAudioStream *astream;
     OGMDvdSubpStream *sstream;
     OGMRipScalerType scaler;
+    gboolean forced;
 
-    GString *options, *pp;
-    guint max_width, max_height;
-    guint scale_width, scale_height;
-    guint crop_x, crop_y, crop_width, crop_height;
-    gboolean crop, expand, forced;
+    argv = ogmrip_mencoder_command_new (output, TRUE);
 
     astream = ogmrip_video_codec_get_ensure_sync (video);
+    ogmrip_mplayer_set_aid (argv, astream);
+
     if (astream)
     {
       g_ptr_array_add (argv, g_strdup ("-oac"));
@@ -646,153 +749,28 @@ ogmrip_mencoder_video_command (OGMRipVideoCodec *video, const gchar *output, gui
       g_ptr_array_add (argv, g_strdup ("8000"));
       g_ptr_array_add (argv, g_strdup ("-af"));
       g_ptr_array_add (argv, g_strdup ("channels=1,lavcresample=8000"));
-      g_ptr_array_add (argv, g_strdup ("-aid"));
-      g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_mplayer_map_audio_id (astream)));
     }
-    else
-      g_ptr_array_add (argv, g_strdup ("-nosound"));
 
     sstream = ogmrip_video_codec_get_hard_subp (video, &forced);
-    if (sstream)
-    {
-      g_ptr_array_add (argv, g_strdup ("-spuaa"));
-      g_ptr_array_add (argv, g_strdup ("20"));
-      g_ptr_array_add (argv, g_strdup ("-sid"));
-      g_ptr_array_add (argv, g_strdup_printf ("%d",
-            ogmdvd_stream_get_id (OGMDVD_STREAM (sstream))));
-
-      if (forced)
-        g_ptr_array_add (argv, g_strdup ("-forcedsubsonly"));
-    }
-    else if (ogmrip_check_mplayer_nosub ())
-      g_ptr_array_add (argv, g_strdup ("-nosub"));
+    ogmrip_mplayer_set_sid (argv, sstream, forced);
 
     scaler = ogmrip_video_codec_get_scaler (video);
     g_ptr_array_add (argv, g_strdup ("-sws"));
     g_ptr_array_add (argv, g_strdup_printf ("%d", MAX (scaler, 0)));
 
-    scale = ogmrip_video_codec_get_scale_size (video, &scale_width, &scale_height);
-
-    options = g_string_new (NULL);
-    pp = g_string_new (NULL);
-
-    if (ogmrip_video_codec_get_deblock (video))
-    {
-      if (pp->len > 0)
-        g_string_append_c (pp, '/');
-      g_string_append (pp, "ha/va");
-    }
-
-    if (ogmrip_video_codec_get_dering (video))
-    {
-      if (pp->len > 0)
-        g_string_append_c (pp, '/');
-      g_string_append (pp, "dr");
-    }
-
-    if (ogmrip_codec_get_telecine (OGMRIP_CODEC (video)))
-    {
-      if (options->len > 0)
-        g_string_append_c (options, ',');
-      g_string_append (options, "pullup,softskip");
-    }
-
-    crop = ogmrip_video_codec_get_crop_size (video, &crop_x, &crop_y, &crop_width, &crop_height);
-    if (crop)
-    {
-      if (options->len > 0)
-        g_string_append_c (options, ',');
-      g_string_append_printf (options, "crop=%u:%u:%u:%u", crop_width, crop_height, crop_x, crop_y);
-    }
-
-    ogmrip_mplayer_set_deint (video, argv, options, pp);
-
-    if (pp->len > 0)
-    {
-      if (options->len > 0)
-        g_string_append_c (options, ',');
-      g_string_append_printf (options, "pp=%s", pp->str);
-    }
-    g_string_free (pp, TRUE);
-
-    if (scale)
-    {
-      if (options->len > 0)
-        g_string_append_c (options, ',');
-      g_string_append_printf (options, "scale=%u:%u", scale_width, scale_height);
-
-      if (ogmrip_video_codec_is_interlaced (video) > 0 && ogmrip_video_codec_get_deinterlacer (video) == OGMRIP_DEINT_NONE)
-        g_string_append (options, ":1");
-    }
-
-    if (ogmrip_video_codec_get_max_size (video, &max_width, &max_height, &expand) && expand)
-    {
-      if (options->len > 0)
-        g_string_append_c (options, ',');
-      g_string_append_printf (options, "expand=%u:%u", max_width, max_height);
-    }
-
-    if (ogmrip_video_codec_get_denoise (video))
-    {
-      if (options->len > 0)
-        g_string_append_c (options, ',');
-      g_string_append (options, "hqdn3d=2:1:2");
-    }
-
-    if (options->len > 0)
-      g_string_append_c (options, ',');
-    g_string_append (options, "harddup");
-
-    if (options->len == 0)
-      g_string_free (options, TRUE);
-    else
-    {
-      g_ptr_array_add (argv, g_strdup ("-vf"));
-      g_ptr_array_add (argv, g_string_free (options, FALSE));
-    }
-
-    ofps = ogmrip_mplayer_get_output_fps (OGMRIP_CODEC (video), title);
-    if (ofps)
-    {
-      g_ptr_array_add (argv, g_strdup ("-ofps"));
-      g_ptr_array_add (argv, ofps);
-    }
+    scale = ogmrip_mplayer_set_video_filter (argv, video);
+    ogmrip_mplayer_set_output_fps (argv, OGMRIP_CODEC (video), title);
   }
 
   g_ptr_array_add (argv, g_strdup (scale ? "-zoom": "-nozoom"));
 
-  chap = ogmrip_mplayer_get_chapters (OGMRIP_CODEC (video), title);
-  if (chap)
-  {
-    g_ptr_array_add (argv, g_strdup ("-chapter"));
-    g_ptr_array_add (argv, chap);
-  }
-
-  start = ogmrip_codec_get_start (OGMRIP_CODEC (video));
-  if (start > 0.0)
-  {
-    g_ptr_array_add (argv, g_strdup ("-ss"));
-    g_ptr_array_add (argv, g_strdup_printf ("%.0lf", start));
-  }
-
-  length = ogmrip_codec_get_play_length (OGMRIP_CODEC (video));
-  if (length > 0.0)
-  {
-    guint num, denom;
-
-    ogmrip_codec_get_framerate (OGMRIP_CODEC (video), &num, &denom);
-    g_ptr_array_add (argv, g_strdup ("-frames"));
-    g_ptr_array_add (argv, g_strdup_printf ("%.0lf", length * num / denom));
-  }
-
+  ogmrip_mplayer_set_chapters (argv, OGMRIP_CODEC (video), title);
+  ogmrip_mplayer_set_start_length (argv, OGMRIP_CODEC (video));
   ogmrip_mplayer_append_edl (OGMRIP_CODEC (video), argv, TRUE);
 
   g_ptr_array_add (argv, g_strdup ("-dvdangle"));
   g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_video_codec_get_angle (video)));
 
-  g_ptr_array_add (argv, g_strdup ("-o"));
-  g_ptr_array_add (argv, g_strdup (output));
-
   device = ogmdvd_disc_get_device (ogmdvd_title_get_disc (title));
   g_ptr_array_add (argv, g_strdup ("-dvd-device"));
   g_ptr_array_add (argv, g_strdup (device));
@@ -842,9 +820,7 @@ ogmrip_mplayer_video_command (OGMRipVideoCodec *video, const gchar *output)
 
   gint format;
   const gchar *device;
-  gdouble start, length;
-  gboolean forced, scale;
-  gchar *chap;
+  gboolean forced, scale = FALSE;
 
   g_return_val_if_fail (OGMRIP_IS_VIDEO_CODEC (video), NULL);
 
@@ -856,131 +832,21 @@ ogmrip_mplayer_video_command (OGMRipVideoCodec *video, const gchar *output)
 
   format = ogmrip_plugin_get_video_codec_format (G_OBJECT_TYPE (video));
 
-  argv = g_ptr_array_new ();
-
-  g_ptr_array_add (argv, g_strdup ("mplayer"));
-  g_ptr_array_add (argv, g_strdup ("-nolirc"));
-  g_ptr_array_add (argv, g_strdup ("-nocache"));
-  g_ptr_array_add (argv, g_strdup ("-noframedrop"));
-  g_ptr_array_add (argv, g_strdup ("-nosound"));
-  g_ptr_array_add (argv, g_strdup ("-noslices"));
-
-  if (MPLAYER_CHECK_VERSION (1,0,3,0))
-  {
-    g_ptr_array_add (argv, g_strdup ("-noconfig"));
-    g_ptr_array_add (argv, g_strdup ("all"));
-  }
+  argv = ogmrip_mplayer_command_new (TRUE);
+  ogmrip_mplayer_set_aid (argv, NULL);
 
   sstream = ogmrip_video_codec_get_hard_subp (video, &forced);
-  if (sstream)
-  {
-    g_ptr_array_add (argv, g_strdup ("-spuaa"));
-    g_ptr_array_add (argv, g_strdup ("20"));
-    g_ptr_array_add (argv, g_strdup ("-sid"));
-    g_ptr_array_add (argv, g_strdup_printf ("%d",
-          ogmdvd_stream_get_id (OGMDVD_STREAM (sstream))));
-
-    if (forced)
-      g_ptr_array_add (argv, g_strdup ("-forcedsubsonly"));
-  }
-  else if (ogmrip_check_mplayer_nosub ())
-    g_ptr_array_add (argv, g_strdup ("-nosub"));
-
-  scale = FALSE;
+  ogmrip_mplayer_set_sid (argv, sstream, forced);
 
   if (format != OGMRIP_FORMAT_COPY)
   {
     OGMRipScalerType scaler;
 
-    GString *options, *pp;
-    guint max_width, max_height;
-    guint crop_x, crop_y, crop_width, crop_height;
-    guint scale_width, scale_height;
-    gboolean crop, expand;
-
     scaler = ogmrip_video_codec_get_scaler (video);
     g_ptr_array_add (argv, g_strdup ("-sws"));
     g_ptr_array_add (argv, g_strdup_printf ("%d", MAX (scaler, 0)));
 
-    scale = ogmrip_video_codec_get_scale_size (video, &scale_width, &scale_height);
-
-    options = g_string_new (NULL);
-    pp = g_string_new (NULL);
-
-    if (ogmrip_video_codec_get_deblock (video))
-    {
-      if (pp->len > 0)
-        g_string_append_c (pp, '/');
-      g_string_append (pp, "ha/va");
-    }
-
-    if (ogmrip_video_codec_get_dering (video))
-    {
-      if (pp->len > 0)
-        g_string_append_c (pp, '/');
-      g_string_append (pp, "dr");
-    }
-
-    if (ogmrip_codec_get_telecine (OGMRIP_CODEC (video)))
-    {
-      if (options->len > 0)
-        g_string_append_c (options, ',');
-      g_string_append (options, "pullup,softskip");
-    }
-
-    crop = ogmrip_video_codec_get_crop_size (video, &crop_x, &crop_y, &crop_width, &crop_height);
-    if (crop)
-    {
-      if (options->len > 0)
-        g_string_append_c (options, ',');
-      g_string_append_printf (options, "crop=%u:%u:%u:%u", crop_width, crop_height, crop_x, crop_y);
-    }
-
-    ogmrip_mplayer_set_deint (video, argv, options, pp);
-
-    if (pp->len > 0)
-    {
-      if (options->len > 0)
-        g_string_append_c (options, ',');
-      g_string_append_printf (options, "pp=%s", pp->str);
-    }
-    g_string_free (pp, TRUE);
-
-    if (scale)
-    {
-      if (options->len > 0)
-        g_string_append_c (options, ',');
-      g_string_append_printf (options, "scale=%u:%u", scale_width, scale_height);
-
-      if (ogmrip_video_codec_is_interlaced (video) > 0 && ogmrip_video_codec_get_deinterlacer (video) == OGMRIP_DEINT_NONE)
-        g_string_append (options, ":1");
-    }
-
-    if (ogmrip_video_codec_get_max_size (video, &max_width, &max_height, &expand) && expand)
-    {
-      if (options->len > 0)
-        g_string_append_c (options, ',');
-      g_string_append_printf (options, "expand=%u:%u", max_width, max_height);
-    }
-
-    if (ogmrip_video_codec_get_denoise (video))
-    {
-      if (options->len > 0)
-        g_string_append_c (options, ',');
-      g_string_append (options, "hqdn3d=2:1:2");
-    }
-
-    if (options->len > 0)
-      g_string_append_c (options, ',');
-    g_string_append (options, "harddup");
-
-    if (options->len == 0)
-      g_string_free (options, TRUE);
-    else
-    {
-      g_ptr_array_add (argv, g_strdup ("-vf"));
-      g_ptr_array_add (argv, g_string_free (options, FALSE));
-    }
+    scale = ogmrip_mplayer_set_video_filter (argv, video);
   }
 
   g_ptr_array_add (argv, g_strdup (scale ? "-zoom" : "-nozoom"));
@@ -988,30 +854,8 @@ ogmrip_mplayer_video_command (OGMRipVideoCodec *video, const gchar *output)
   g_ptr_array_add (argv, g_strdup ("-dvdangle"));
   g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_video_codec_get_angle (video)));
 
-  chap = ogmrip_mplayer_get_chapters (OGMRIP_CODEC (video), title);
-  if (chap)
-  {
-    g_ptr_array_add (argv, g_strdup ("-chapter"));
-    g_ptr_array_add (argv, chap);
-  }
-
-  start = ogmrip_codec_get_start (OGMRIP_CODEC (video));
-  if (start > 0.0)
-  {
-    g_ptr_array_add (argv, g_strdup ("-ss"));
-    g_ptr_array_add (argv, g_strdup_printf ("%.0lf", start));
-  }
-
-  length = ogmrip_codec_get_play_length (OGMRIP_CODEC (video));
-  if (length > 0.0)
-  {
-    guint num, denom;
-
-    ogmrip_codec_get_framerate (OGMRIP_CODEC (video), &num, &denom);
-    g_ptr_array_add (argv, g_strdup ("-frames"));
-    g_ptr_array_add (argv, g_strdup_printf ("%.0lf", length * num / denom));
-  }
-
+  ogmrip_mplayer_set_chapters (argv, OGMRIP_CODEC (video), title);
+  ogmrip_mplayer_set_start_length (argv, OGMRIP_CODEC (video));
   ogmrip_mplayer_append_edl (OGMRIP_CODEC (video), argv, FALSE);
 
   device = ogmdvd_disc_get_device (ogmdvd_title_get_disc (title));
@@ -1065,10 +909,7 @@ ogmrip_mencoder_vobsub_command (OGMRipSubpCodec *subp, const gchar *output)
   OGMDvdSubpStream *sstream;
 
   GPtrArray *argv;
-  gdouble start, length;
-  const gchar *device;
-  gchar *ofps, *chap;
-  gint vid, sid;
+  gint sid;
 
   g_return_val_if_fail (OGMRIP_IS_SUBP_CODEC (subp), NULL);
 
@@ -1082,16 +923,8 @@ ogmrip_mencoder_vobsub_command (OGMRipSubpCodec *subp, const gchar *output)
   sstream = ogmrip_subp_codec_get_dvd_subp_stream (OGMRIP_SUBP_CODEC (subp));
   g_return_val_if_fail (sstream != NULL, NULL);
 
-  argv = g_ptr_array_new ();
-  g_ptr_array_add (argv, g_strdup ("mencoder"));
-  g_ptr_array_add (argv, g_strdup ("-nocache"));
-  g_ptr_array_add (argv, g_strdup ("-nosound"));
-
-  if (MPLAYER_CHECK_VERSION (1,0,3,0))
-  {
-    g_ptr_array_add (argv, g_strdup ("-noconfig"));
-    g_ptr_array_add (argv, g_strdup ("all"));
-  }
+  argv = ogmrip_mencoder_command_new ("/dev/null", TRUE);
+  ogmrip_mplayer_set_aid (argv, NULL);
 
   if (MPLAYER_CHECK_VERSION (1,0,0,8))
   {
@@ -1102,15 +935,7 @@ ogmrip_mencoder_vobsub_command (OGMRipSubpCodec *subp, const gchar *output)
   g_ptr_array_add (argv, g_strdup ("-ovc"));
   g_ptr_array_add (argv, g_strdup ("copy"));
 
-  ofps = ogmrip_mplayer_get_output_fps (OGMRIP_CODEC (subp), title);
-  if (ofps)
-  {
-    g_ptr_array_add (argv, g_strdup ("-ofps"));
-    g_ptr_array_add (argv, ofps);
-  }
-
-  g_ptr_array_add (argv, g_strdup ("-o"));
-  g_ptr_array_add (argv, g_strdup ("/dev/null"));
+  ogmrip_mplayer_set_output_fps (argv, OGMRIP_CODEC (subp), title);
 
   sid = ogmdvd_stream_get_id (OGMDVD_STREAM (sstream));
   g_ptr_array_add (argv, g_strdup ("-vobsubout"));
@@ -1120,45 +945,11 @@ ogmrip_mencoder_vobsub_command (OGMRipSubpCodec *subp, const gchar *output)
   g_ptr_array_add (argv, g_strdup ("-sid"));
   g_ptr_array_add (argv, g_strdup_printf ("%d", sid));
 
-  chap = ogmrip_mplayer_get_chapters (OGMRIP_CODEC (subp), title);
-  if (chap)
-  {
-    g_ptr_array_add (argv, g_strdup ("-chapter"));
-    g_ptr_array_add (argv, chap);
-  }
-
-  start = ogmrip_codec_get_start (OGMRIP_CODEC (subp));
-  if (start > 0.0)
-  {
-    g_ptr_array_add (argv, g_strdup ("-ss"));
-    g_ptr_array_add (argv, g_strdup_printf ("%.0lf", start));
-  }
-
-  length = ogmrip_codec_get_play_length (OGMRIP_CODEC (subp));
-  if (length > 0.0)
-  {
-    guint num, denom;
-
-    ogmrip_codec_get_framerate (OGMRIP_CODEC (subp), &num, &denom);
-    g_ptr_array_add (argv, g_strdup ("-frames"));
-    g_ptr_array_add (argv, g_strdup_printf ("%.0lf", length * num / denom));
-  }
-
+  ogmrip_mplayer_set_chapters (argv, OGMRIP_CODEC (subp), title);
+  ogmrip_mplayer_set_start_length (argv, OGMRIP_CODEC (subp));
   ogmrip_mplayer_append_edl (OGMRIP_CODEC (subp), argv, TRUE);
 
-  device = ogmdvd_disc_get_device (ogmdvd_title_get_disc (title));
-  g_ptr_array_add (argv, g_strdup ("-dvd-device"));
-  g_ptr_array_add (argv, g_strdup (device));
-
-  vid = ogmdvd_title_get_nr (title);
-
-  if (MPLAYER_CHECK_VERSION (1,0,0,1))
-    g_ptr_array_add (argv, g_strdup_printf ("dvd://%d", vid + 1));
-  else
-  {
-    g_ptr_array_add (argv, g_strdup ("-dvd"));
-    g_ptr_array_add (argv, g_strdup_printf ("%d", vid + 1));
-  }
+  ogmrip_mplayer_set_input (argv, title);
 
   g_ptr_array_add (argv, NULL);
 
@@ -1306,17 +1097,9 @@ ogmrip_mencoder_container_command (OGMRipContainer *container)
   GPtrArray *argv;
   const gchar *fourcc;
 
-  argv = g_ptr_array_new ();
-  g_ptr_array_add (argv, g_strdup ("mencoder"));
-  g_ptr_array_add (argv, g_strdup ("-nocache"));
+  argv = ogmrip_mencoder_command_new (NULL, TRUE);
   g_ptr_array_add (argv, g_strdup ("-noskip"));
 
-  if (MPLAYER_CHECK_VERSION (1,0,3,0))
-  {
-    g_ptr_array_add (argv, g_strdup ("-noconfig"));
-    g_ptr_array_add (argv, g_strdup ("all"));
-  }
-
   g_ptr_array_add (argv, g_strdup ("-mc"));
   g_ptr_array_add (argv, g_strdup ("0"));
 
