@@ -101,9 +101,6 @@ ogmrip_plugin_load (GSList *slist, const gchar *dirname, GType type)
 
   const gchar *filename;
   gchar *fullname;
-  gint len;
-
-  len = strlen (dirname);
 
   pspec = g_pattern_spec_new ("*.so");
 
