@@ -1,5 +1,5 @@
 /* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,6 +16,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ogmrip-fs.h"
 #include "ogmrip-gconf.h"
 #include "ogmrip-helper.h"
@@ -24,6 +28,7 @@
 #include "ogmrip-gconf-settings.h"
 
 #include <string.h>
+#include <unistd.h>
 
 OGMRipSettings *settings;
 
@@ -122,8 +127,14 @@ ogmrip_gconf_init (void)
       g_param_spec_int (OGMRIP_GCONF_CHAPTER_LANG, NULL, NULL, 0, G_MAXINT, OGMRIP_DEFAULT_CHAPTER_LANG, G_PARAM_READWRITE));
   ogmrip_settings_install_key (settings,
       g_param_spec_int (OGMRIP_GCONF_AFTER_ENC, NULL, NULL, 0, 3, OGMRIP_DEFAULT_AFTER_ENC, G_PARAM_READWRITE));
+
+#ifdef HAVE_SYSCONF_NPROC
+  ogmrip_settings_install_key (settings,
+      g_param_spec_int (OGMRIP_GCONF_THREADS, NULL, NULL, 1, G_MAXINT, sysconf (_SC_NPROCESSORS_ONLN), G_PARAM_READWRITE));
+#else
   ogmrip_settings_install_key (settings,
       g_param_spec_int (OGMRIP_GCONF_THREADS, NULL, NULL, 1, G_MAXINT, OGMRIP_DEFAULT_THREADS, G_PARAM_READWRITE));
+#endif
 
   ogmrip_settings_install_key (settings,
       g_param_spec_boolean (OGMRIP_GCONF_COPY_DVD, NULL, NULL, OGMRIP_DEFAULT_COPY_DVD, G_PARAM_READWRITE));
@@ -184,7 +195,7 @@ ogmrip_gconf_init (void)
   ogmrip_settings_install_key (settings,
       g_param_spec_int (OGMRIP_GCONF_VIDEO_BITRATE, NULL, NULL, 4, 16000, OGMRIP_DEFAULT_VIDEO_BITRATE, G_PARAM_READWRITE));
   ogmrip_settings_install_key (settings,
-      g_param_spec_double (OGMRIP_GCONF_VIDEO_QUANTIZER, NULL, NULL, 1, 31, OGMRIP_DEFAULT_VIDEO_QUANTIZER, G_PARAM_READWRITE));
+      g_param_spec_double (OGMRIP_GCONF_VIDEO_QUANTIZER, NULL, NULL, 0, 31, OGMRIP_DEFAULT_VIDEO_QUANTIZER, G_PARAM_READWRITE));
   ogmrip_settings_install_key (settings,
       g_param_spec_double (OGMRIP_GCONF_VIDEO_BPP, NULL, NULL, 0.0, G_MAXDOUBLE, OGMRIP_DEFAULT_VIDEO_BPP, G_PARAM_READWRITE));
 
