@@ -1,5 +1,5 @@
 /* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -611,7 +611,9 @@ ogmrip_queue_dialog_init (OGMRipQueueDialog *dialog)
 
   gtk_window_set_title (GTK_WINDOW (dialog), _("Encoding Queue"));
   gtk_window_set_default_size (GTK_WINDOW (dialog), 500, 300);
+#if !GTK_CHECK_VERSION(2,22,0)
   gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+#endif
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
   gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT, FALSE);
   gtk_window_set_icon_from_stock (GTK_WINDOW (dialog), GTK_STOCK_PROPERTIES);
@@ -640,11 +642,13 @@ ogmrip_queue_dialog_init (OGMRipQueueDialog *dialog)
   dialog->priv->import_action = gtk_action_group_get_action (action_group, "Import");
   g_signal_connect_swapped (dialog->priv->import_action, "activate",
       G_CALLBACK (ogmrip_queue_dialog_import_action_activated), dialog);
+  gtk_action_set_visible (dialog->priv->import_action, FALSE);
 
   dialog->priv->export_action = gtk_action_group_get_action (action_group, "Export");
   gtk_action_set_sensitive (dialog->priv->export_action, FALSE);
   g_signal_connect_swapped (dialog->priv->export_action, "activate",
       G_CALLBACK (ogmrip_queue_dialog_export_action_activated), dialog);
+  gtk_action_set_visible (dialog->priv->export_action, FALSE);
 
   area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 
