@@ -1,15 +1,30 @@
-/* SPUdec.c
-   Skeleton of function spudec_process_controll() is from xine sources.
-   Further works:
-   LGB,... (yeah, try to improve it and insert your name here! ;-)
-
-   Kim Minh Kaplan
-   implement fragments reassembly, RLE decoding.
-   read brightness from the IFO.
-
-   For information on SPU format see <URL:http://sam.zoy.org/doc/dvd/subtitles/>
-   and <URL:http://members.aol.com/mpucoder/DVD/spu.html>
-
+/*
+ * Skeleton of function spudec_process_controll() is from xine sources.
+ * Further works:
+ * LGB,... (yeah, try to improve it and insert your name here! ;-)
+ *
+ * Kim Minh Kaplan
+ * implement fragments reassembly, RLE decoding.
+ * read brightness from the IFO.
+ *
+ * For information on SPU format see <URL:http://sam.zoy.org/doc/dvd/subtitles/>
+ * and <URL:http://members.aol.com/mpucoder/DVD/spu.html>
+ *
+ * This file is part of MPlayer.
+ *
+ * MPlayer is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * MPlayer is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with MPlayer; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 // #include "config.h"
 // #include "mp_msg.h"
@@ -26,8 +41,10 @@
 #include "spudec.h"
 #include "vobsub.h"
 // #include "libavutil/avutil.h"
+// #include "libavutil/intreadwrite.h"
 // #include "libswscale/swscale.h"
 #define FFMIN(a,b) ((a) > (b) ? (b) : (a))
+#define FFMAX(a,b) ((a) < (b) ? (b) : (a))
 
 /* Valid values for spu_aamode:
    0: none (fastest, most ugly)
@@ -161,15 +178,10 @@ static inline unsigned char get_nibble(packet_t *packet)
 static inline int mkalpha(int i)
 {
   /* In mplayer's alpha planes, 0 is transparent, then 1 is nearly
-     opaque upto 255 which is transparent */
-  switch (i) {
-  case 0xf:
-    return 1;
-  case 0:
-    return 0;
-  default:
-    return (0xf - i) << 4;
-  }
+     opaque upto 255 which is fully opaque */
+  // extend 4 -> 8 bit
+  i |= i << 4;
+  return (uint8_t)(-i);
 }
 
 /* Cut the sub to visible part */
@@ -199,7 +211,7 @@ static inline void spudec_cut_image(spudec_handle_t *this)
 	  this->image_size = 0;
 	  return;
   }
-  
+
 //  printf("new h %d new start %d (sz %d st %d)---\n\n", this->height, this->start_row, this->image_size, this->stride);
 
   image = malloc(2 * this->stride * this->height);
@@ -386,7 +398,7 @@ static void normalize_palette(spudec_handle_t *this, packet_t *packet)
 
 static void spudec_process_control(spudec_handle_t *this, int pts100)
 {
-  int a,b; /* Temporary vars */
+  int a,b,c,d; /* Temporary vars */
   unsigned int date, type;
   unsigned int off;
   unsigned int start_off = 0;
@@ -449,10 +461,22 @@ static void spudec_process_control(spudec_handle_t *this, int pts100)
 	break;
       case 0x04:
 	/* Alpha */
-	this->alpha[0] = this->packet[off] >> 4;
-	this->alpha[1] = this->packet[off] & 0xf;
-	this->alpha[2] = this->packet[off + 1] >> 4;
-	this->alpha[3] = this->packet[off + 1] & 0xf;
+	a = this->packet[off] >> 4;
+	b = this->packet[off] & 0xf;
+	c = this->packet[off + 1] >> 4;
+	d = this->packet[off + 1] & 0xf;
+	// Note: some DVDs change these values to create a fade-in/fade-out effect
+	// We can not handle this, so just keep the highest value during the display time.
+	if (display) {
+		a = FFMAX(a, this->alpha[0]);
+		b = FFMAX(b, this->alpha[1]);
+		c = FFMAX(c, this->alpha[2]);
+		d = FFMAX(d, this->alpha[3]);
+	}
+	this->alpha[0] = a;
+	this->alpha[1] = b;
+	this->alpha[2] = c;
+	this->alpha[3] = d;
 	mp_msg(MSGT_SPUDEC,MSGL_DBG2,"Alpha %d, %d, %d, %d\n",
 	       this->alpha[0], this->alpha[1], this->alpha[2], this->alpha[3]);
 	off+=2;
@@ -555,12 +579,6 @@ void spudec_assemble(void *this, unsigned char *packet, unsigned int len, int pt
       mp_msg(MSGT_SPUDEC,MSGL_WARN,"SPUasm: packet too short\n");
       return;
   }
-#if 0
-  if ((spu->packet_pts + 10000) < pts100) {
-    // [cb] too long since last fragment: force new packet
-    spu->packet_offset = 0;
-  }
-#endif
   spu->packet_pts = pts100;
   if (spu->packet_offset == 0) {
     unsigned int len2 = get_be16(packet);
@@ -638,7 +656,7 @@ void spudec_reset(void *this)	// called after seek
 }
 
 void spudec_heartbeat(void *this, unsigned int pts100)
-{ 
+{
   spudec_handle_t *spu = (spudec_handle_t*) this;
   spu->now_pts = pts100;
 
@@ -791,8 +809,9 @@ static void scale_image(int x, int y, scale_pixel* table_x, scale_pixel* table_y
   }
 }
 
-void sws_spu_image(unsigned char *d1, unsigned char *d2, int dw, int dh, int ds,
-	unsigned char *s1, unsigned char *s2, int sw, int sh, int ss)
+static void sws_spu_image(unsigned char *d1, unsigned char *d2, int dw, int dh,
+                          int ds, unsigned char *s1, unsigned char *s2, int sw,
+                          int sh, int ss)
 {
 /*
 	struct SwsContext *ctx;
@@ -809,7 +828,7 @@ void sws_spu_image(unsigned char *d1, unsigned char *d2, int dw, int dh, int ds,
 		firsttime = 0;
 		oldvar = spu_gaussvar;
 	}
-	
+
 	ctx=sws_getContext(sw, sh, PIX_FMT_GRAY8, dw, dh, PIX_FMT_GRAY8, SWS_GAUSS, &filter, NULL, NULL);
 	sws_scale(ctx,&s1,&ss,0,sh,&d1,&ds);
 	for (i=ss*sh-1; i>=0; i--) if (!s2[i]) s2[i] = 255; //else s2[i] = 1;
@@ -828,7 +847,7 @@ void spudec_draw_scaled(void *me, unsigned int dxs, unsigned int dys, void (*dra
   if (spu->start_pts <= spu->now_pts && spu->now_pts < spu->end_pts) {
 
     // check if only forced subtitles are requested 
-    if( (spu->forced_subs_only) && !(spu->is_forced_sub) ){ 
+    if( (spu->forced_subs_only) && !(spu->is_forced_sub) ){
 	return;
     }
 
@@ -952,7 +971,7 @@ void spudec_draw_scaled(void *me, unsigned int dxs, unsigned int dys, void (*dra
 
 	       The original rectangular region that the scaled pixel
 	       represents is cut in 9 rectangular areas like this:
-	       
+
 	       +---+-----------------+---+
 	       | 1 |        2        | 3 |
 	       +---+-----------------+---+
@@ -1061,7 +1080,7 @@ void spudec_draw_scaled(void *me, unsigned int dxs, unsigned int dys, void (*dra
 		      alpha += tmp;
 		      color += tmp * spu->image[base + walkx];
 		    }
-		  }		    
+		  }
 		}
 		/* 6: center right part */
 		if (right > 0.0 && height > 0) {
@@ -1194,9 +1213,13 @@ static void spudec_parse_extradata(spudec_handle_t *this,
   buffer[extradata_len] = 0;
 
   do {
-    sscanf(ptr, "size: %dx%d", &this->orig_frame_width, &this->orig_frame_height);
-    if (sscanf(ptr, "palette: %x, %x, %x, %x, %x, %x, %x, %x,"
-                            " %x, %x, %x, %x, %x, %x, %x, %x",
+    if (*ptr == '#')
+        continue;
+    if (!strncmp(ptr, "size: ", 6))
+        sscanf(ptr + 6, "%dx%d", &this->orig_frame_width, &this->orig_frame_height);
+    if (!strncmp(ptr, "palette: ", 9) &&
+        sscanf(ptr + 9, "%x, %x, %x, %x, %x, %x, %x, %x, "
+                        "%x, %x, %x, %x, %x, %x, %x, %x",
                &pal[ 0], &pal[ 1], &pal[ 2], &pal[ 3],
                &pal[ 4], &pal[ 5], &pal[ 6], &pal[ 7],
                &pal[ 8], &pal[ 9], &pal[10], &pal[11],
@@ -1207,7 +1230,8 @@ static void spudec_parse_extradata(spudec_handle_t *this,
     }
     if (!strncasecmp(ptr, "forced subs: on", 15))
       this->forced_subs_only = 1;
-    if (sscanf(ptr, "custom colors: ON, tridx: %x, colors: %x, %x, %x, %x",
+    if (!strncmp(ptr, "custom colors: ON, tridx: ", 26) &&
+        sscanf(ptr + 26, "%x, colors: %x, %x, %x, %x",
                &tridx, cuspal+0, cuspal+1, cuspal+2, cuspal+3) == 5) {
       for (i=0; i<4; i++) {
         cuspal[i] = vobsub_rgb_to_yuv(cuspal[i]);
@@ -1272,7 +1296,6 @@ void spudec_set_hw_spu(void *this, const vo_functions_t *hw_spu)
   spudec_handle_t *spu = (spudec_handle_t*)this;
   if (!spu)
     return;
-
   spu->hw_spu = hw_spu;
   hw_spu->control(VOCTRL_SET_SPU_PALETTE,spu->global_palette);
 }
